tweak

package
v0.0.0-...-9a5de48 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 7, 2025 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ChainTweak

func ChainTweak(epoch uint32, chainIndex uint8, posInChain uint8) th.Tweak

ChainTweak creates a tweak for hash chain operations Implements Eq. (17) from the paper: tweak(ep,i,k)

func MessageTweak

func MessageTweak(epoch uint32) th.Tweak

MessageTweak creates a tweak for message hashing Implements Eq. (19) from the paper: tweakm(ep) NOTE: Uses little-endian for epoch to match Rust implementation

func TreeTweak

func TreeTweak(level uint8, posInLevel uint32) th.Tweak

TreeTweak creates a tweak for Merkle tree operations Implements Eq. (18) from the paper: tweakmt(l,i)

Types

This section is empty.

Jump to