Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ChainTweak ¶
ChainTweak creates a tweak for hash chain operations Implements Eq. (17) from the paper: tweak(ep,i,k)
func MessageTweak ¶
MessageTweak creates a tweak for message hashing Implements Eq. (19) from the paper: tweakm(ep) NOTE: Uses little-endian for epoch to match Rust implementation
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.